@@ -975,6 +975,14 @@ LookupSpecialAccessions() {
           ids=$( echo "$rem $lcl" | fmt -w 1 | sort -n | uniq )
         fi
         ;;
+      taxonomy )
+        acc=$( ExtractAccns )
+        if [ -n "$acc" ]
+        then
+          echo "ERROR: Taxonomy database does not index sequence accession numbers" >&2
+          exit 1
+        fi
+        ;;
     esac
     if [ -n "$fld" ]
     then
